@@ -56,6 +56,8 @@ def get_config_file():
             input = json.load(open(sys.argv[1]))
             if 'config_files' in input and len(input['config_files']) > 1:
                 return input['config_files'][0]
+            elif 'configuration' in input:
+                return json.dumps(input['configuration'])
             return None
         else:
             return None
@@ -98,4 +100,4 @@ def update_progress(percent, message):
         sys.stderr.write("Percent done: {}\n".format(percent))
         
 def is_running_on_wivi_server():
-    return is_wivi
+    return is_wivi
\ No newline at end of file
